@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This module is a scratchpad for general development, testing & debugging.
 """
@@ -20,13 +19,15 @@ class Command(NoArgsCommand):
         Project.objects.all().delete()
         a = Project.objects.create(topic="John's gathering")
         b = ArtProject.objects.create(topic="Sculpting with Tim", artist="T. Turner")
-        c = ResearchProject.objects.create(topic="Swallow Aerodynamics", supervisor="Dr. Winter")
-        print Project.objects.all()
-        print
+        c = ResearchProject.objects.create(
+            topic="Swallow Aerodynamics", supervisor="Dr. Winter"
+        )
+        print(Project.objects.all())
+        print("")
 
         TestModelA.objects.all().delete()
-        a = TestModelA.objects.create(field1='A1')
-        b = TestModelB.objects.create(field1='B1', field2='B2')
-        c = TestModelC.objects.create(field1='C1', field2='C2', field3='C3')
-        print TestModelA.objects.all()
-        print
+        a = TestModelA.objects.create(field1="A1")
+        b = TestModelB.objects.create(field1="B1", field2="B2")
+        c = TestModelC.objects.create(field1="C1", field2="C2", field3="C3")
+        print(TestModelA.objects.all())
+        print("")
