@@ -15,5 +15,7 @@ class Command(BaseCommand):
         Project.objects.all().delete()
         o = Project.objects.create(topic="John's gathering")
         o = ArtProject.objects.create(topic="Sculpting with Tim", artist="T. Turner")
-        o = ResearchProject.objects.create(topic="Swallow Aerodynamics", supervisor="Dr. Winter")
+        o = ResearchProject.objects.create(
+            topic="Swallow Aerodynamics", supervisor="Dr. Winter"
+        )
         print(Project.objects.all())
