@@ -2,17 +2,14 @@
 """
 The manager class for use in the models.
 """
-from __future__ import unicode_literals
 
 from django.db import models
 
-from polymorphic.compat import python_2_unicode_compatible
 from polymorphic.query import PolymorphicQuerySet
 
 __all__ = ("PolymorphicManager", "PolymorphicQuerySet")
 
 
-@python_2_unicode_compatible
 class PolymorphicManager(models.Manager):
     """
     Manager for PolymorphicModel
