@@ -2,16 +2,14 @@
 """
 QuerySet for PolymorphicModel
 """
-from __future__ import absolute_import
-
 import copy
 from collections import defaultdict
 
+from django import get_version as get_django_version
 from django.contrib.contenttypes.models import ContentType
-from django.db.models import FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist
 from django.db.models.query import ModelIterable, Q, QuerySet
 
-from . import compat
 from .query_translate import (
     translate_polymorphic_field_path,
     translate_polymorphic_filter_definitions_in_args,
@@ -160,24 +158,40 @@ class PolymorphicQuerySet(QuerySet):
         # Implementation in _translate_polymorphic_filter_defnition."""
         return self.filter(not_instance_of=args)
 
-    def _filter_or_exclude(self, negate, *args, **kwargs):
-        # We override this internal Django functon as it is used for all filter member functions.
-        q_objects = translate_polymorphic_filter_definitions_in_args(
-            self.model, args, using=self.db
-        )
-        # filter_field='data'
-        additional_args = translate_polymorphic_filter_definitions_in_kwargs(
-            self.model, kwargs, using=self.db
-        )
-        return super(PolymorphicQuerySet, self)._filter_or_exclude(
-            negate, *(list(q_objects) + additional_args), **kwargs
-        )
+    # Makes _filter_or_exclude compatible with the change in signature introduced in django at 9c9a3fe
+    if get_django_version() >= "3.2":
+        def _filter_or_exclude(self, negate, args, kwargs):
+            # We override this internal Django function as it is used for all filter member functions.
+            q_objects = translate_polymorphic_filter_definitions_in_args(
+                queryset_model=self.model, args=args, using=self.db
+            )
+            # filter_field='data'
+            additional_args = translate_polymorphic_filter_definitions_in_kwargs(
+                queryset_model=self.model, kwargs=kwargs, using=self.db
+            )
+            args = list(q_objects) + additional_args
+            return super(PolymorphicQuerySet, self)._filter_or_exclude(
+                negate=negate, args=args, kwargs=kwargs
+            )
+    else:
+        def _filter_or_exclude(self, negate, *args, **kwargs):
+            # We override this internal Django function as it is used for all filter member functions.
+            q_objects = translate_polymorphic_filter_definitions_in_args(
+                self.model, args, using=self.db
+            )
+            # filter_field='data'
+            additional_args = translate_polymorphic_filter_definitions_in_kwargs(
+                self.model, kwargs, using=self.db
+            )
+            return super(PolymorphicQuerySet, self)._filter_or_exclude(
+                negate, *(list(q_objects) + additional_args), **kwargs
+            )
 
     def order_by(self, *field_names):
         """translate the field paths in the args, then call vanilla order_by."""
         field_names = [
             translate_polymorphic_field_path(self.model, a)
-            if isinstance(a, compat.string_types)
+            if isinstance(a, str)
             else a  # allow expressions to pass unchanged
             for a in field_names
         ]
@@ -524,4 +538,4 @@ class PolymorphicQuerySet(QuerySet):
         if not self.model.polymorphic_query_multiline_output:
             return olist
         clist = PolymorphicQuerySet._p_list_class(olist)
-        return clist
+        return clist
\ No newline at end of file
