@@ -1450,6 +1450,13 @@ class Migration(migrations.Migration):
                 to="tests.ParentModelWithManager",
             ),
         ),
+        migrations.AddField(
+            model_name="childmodelwithmanager",
+            name="field1",
+            field=models.CharField(
+                max_length=10,
+            ),
+        ),
         migrations.AddField(
             model_name="childmodelwithmanager",
             name="polymorphic_ctype",
