@@ -238,22 +238,12 @@ class PolymorphicTests(TransactionTestCase):
             objects_deferred[0].__dict__,
             "field1 was not deferred (using defer())",
         )
-        self.assertRegex(
-            repr(objects_deferred[0]),
-            r"<Model2A: id \d+, field1 \(CharField\), deferred\[field1\]>",
-        )
-        self.assertRegex(
-            repr(objects_deferred[1]),
-            r"<Model2B: id \d+, field1 \(CharField\), field2 \(CharField\), deferred\[field1\]>",
-        )
-        self.assertRegex(
-            repr(objects_deferred[2]),
-            r"<Model2C: id \d+, field1 \(CharField\), field2 \(CharField\), field3 \(CharField\), deferred\[field1\]>",
-        )
-        self.assertRegex(
-            repr(objects_deferred[3]),
-            r"<Model2D: id \d+, field1 \(CharField\), field2 \(CharField\), field3 \(CharField\), field4 \(CharField\), deferred\[field1\]>",
-        )
+
+        # Check that we have exactly one deferred field ('field1') per resulting object.
+        for obj in objects_deferred:
+            deferred_fields = obj.get_deferred_fields()
+            self.assertEqual(1, len(deferred_fields))
+            self.assertIn("field1", deferred_fields)
 
         objects_only = Model2A.objects.only("pk", "polymorphic_ctype", "field1")
 
@@ -271,48 +261,37 @@ class PolymorphicTests(TransactionTestCase):
         self.assertNotIn(
             "field4", objects_only[3].__dict__, "field4 was not deferred (using only())"
         )
-        self.assertRegex(
-            repr(objects_only[0]), r"<Model2A: id \d+, field1 \(CharField\)>"
-        )
-        self.assertRegex(
-            repr(objects_only[1]),
-            r"<Model2B: id \d+, field1 \(CharField\), field2 \(CharField\), deferred\[field2\]>",
-        )
-        self.assertRegex(
-            repr(objects_only[2]),
-            r"<Model2C: id \d+, field1 \(CharField\), field2 \(CharField\), field3 \(CharField\), "
-            r"deferred\[field2,field3,model2a_ptr_id\]>",
-        )
-        self.assertRegex(
-            repr(objects_only[3]),
-            r"<Model2D: id \d+, field1 \(CharField\), field2 \(CharField\), field3 \(CharField\), field4 \(CharField\), "
-            r"deferred\[field2,field3,field4,model2a_ptr_id,model2b_ptr_id\]>",
-        )
+        self.assertNotIn("field1", objects_only[0].get_deferred_fields())
+
+        self.assertIn("field2", objects_only[1].get_deferred_fields())
+
+        # objects_only[2] has several deferred fields, ensure they are all set as such.
+        model2c_deferred = objects_only[2].get_deferred_fields()
+        self.assertIn("field2", model2c_deferred)
+        self.assertIn("field3", model2c_deferred)
+        self.assertIn("model2a_ptr_id", model2c_deferred)
+
+        # objects_only[3] has a few more fields that should be set as deferred.
+        model2d_deferred = objects_only[3].get_deferred_fields()
+        self.assertIn("field2", model2d_deferred)
+        self.assertIn("field3", model2d_deferred)
+        self.assertIn("field4", model2d_deferred)
+        self.assertIn("model2a_ptr_id", model2d_deferred)
+        self.assertIn("model2b_ptr_id", model2d_deferred)
 
         ModelX.objects.create(field_b="A1", field_x="A2")
         ModelY.objects.create(field_b="B1", field_y="B2")
 
+        # If we defer a field on a descendent, the parent's field is not deferred.
         objects_deferred = Base.objects.defer("ModelY___field_y")
-        self.assertRegex(
-            repr(objects_deferred[0]),
-            r"<ModelX: id \d+, field_b \(CharField\), field_x \(CharField\)>",
-        )
-        self.assertRegex(
-            repr(objects_deferred[1]),
-            r"<ModelY: id \d+, field_b \(CharField\), field_y \(CharField\), deferred\[field_y\]>",
-        )
+        self.assertNotIn("field_y", objects_deferred[0].get_deferred_fields())
+        self.assertIn("field_y", objects_deferred[1].get_deferred_fields())
 
         objects_only = Base.objects.only(
             "polymorphic_ctype", "ModelY___field_y", "ModelX___field_x"
         )
-        self.assertRegex(
-            repr(objects_only[0]),
-            r"<ModelX: id \d+, field_b \(CharField\), field_x \(CharField\), deferred\[field_b\]>",
-        )
-        self.assertRegex(
-            repr(objects_only[1]),
-            r"<ModelY: id \d+, field_b \(CharField\), field_y \(CharField\), deferred\[field_b\]>",
-        )
+        self.assertIn("field_b", objects_only[0].get_deferred_fields())
+        self.assertIn("field_b", objects_only[1].get_deferred_fields())
 
     def test_defer_related_fields(self):
         self.create_model2abcd()
@@ -481,21 +460,22 @@ class PolymorphicTests(TransactionTestCase):
     def test_foreignkey_field(self):
         self.create_model2abcd()
 
-        object2a = Model2A.base_objects.get(field1="C1")
+        object2a = Model2A.objects.get(field1="C1")
         self.assertEqual(object2a.model2b.__class__, Model2B)
 
-        object2b = Model2B.base_objects.get(field1="C1")
+        object2b = Model2B.objects.get(field1="C1")
         self.assertEqual(object2b.model2c.__class__, Model2C)
 
     def test_onetoone_field(self):
         self.create_model2abcd()
 
+        # FIXME: We should not use base_objects here.
         a = Model2A.base_objects.get(field1="C1")
         b = One2OneRelatingModelDerived.objects.create(
             one2one=a, field1="f1", field2="f2"
         )
 
-        # this result is basically wrong, probably due to Django cacheing (we used base_objects), but should not be a problem
+        # FIXME: this result is basically wrong, probably due to Django cacheing (we used base_objects), but should not be a problem
         self.assertEqual(b.one2one.__class__, Model2A)
         self.assertEqual(b.one2one_id, b.one2one.id)
 
@@ -581,32 +561,18 @@ class PolymorphicTests(TransactionTestCase):
             select={"topic": "tests_modelextraexternal.topic"},
             where=["tests_modelextraa.id = tests_modelextraexternal.id"],
         )
-        if compat.PY3:
-            self.assertEqual(
-                repr(objects[0]),
-                '<ModelExtraA: id 1, field1 (CharField) "A1" - Extra: topic (str) "extra1">',
-            )
-            self.assertEqual(
-                repr(objects[1]),
-                '<ModelExtraB: id 2, field1 (CharField) "B1", field2 (CharField) "B2" - Extra: topic (str) "extra2">',
-            )
-            self.assertEqual(
-                repr(objects[2]),
-                '<ModelExtraC: id 3, field1 (CharField) "C1", field2 (CharField) "C2", field3 (CharField) "C3" - Extra: topic (str) "extra3">',
-            )
-        else:
-            self.assertEqual(
-                repr(objects[0]),
-                '<ModelExtraA: id 1, field1 (CharField) "A1" - Extra: topic (unicode) "extra1">',
-            )
-            self.assertEqual(
-                repr(objects[1]),
-                '<ModelExtraB: id 2, field1 (CharField) "B1", field2 (CharField) "B2" - Extra: topic (unicode) "extra2">',
-            )
-            self.assertEqual(
-                repr(objects[2]),
-                '<ModelExtraC: id 3, field1 (CharField) "C1", field2 (CharField) "C2", field3 (CharField) "C3" - Extra: topic (unicode) "extra3">',
-            )
+        self.assertEqual(
+            repr(objects[0]),
+            '<ModelExtraA: id 1, field1 (CharField) "A1" - Extra: topic (str) "extra1">',
+        )
+        self.assertEqual(
+            repr(objects[1]),
+            '<ModelExtraB: id 2, field1 (CharField) "B1", field2 (CharField) "B2" - Extra: topic (str) "extra2">',
+        )
+        self.assertEqual(
+            repr(objects[2]),
+            '<ModelExtraC: id 3, field1 (CharField) "C1", field2 (CharField) "C2", field3 (CharField) "C3" - Extra: topic (str) "extra3">',
+        )
         self.assertEqual(len(objects), 3)
 
     def test_instance_of_filter(self):
@@ -822,7 +788,6 @@ class PolymorphicTests(TransactionTestCase):
 
         self.assertIs(type(ModelWithMyManager.objects), MyManager)
         self.assertIs(type(ModelWithMyManager._default_manager), MyManager)
-        self.assertIs(type(ModelWithMyManager.base_objects), models.Manager)
 
     def test_user_defined_manager_as_secondary(self):
         self.create_model2abcd()
@@ -845,7 +810,6 @@ class PolymorphicTests(TransactionTestCase):
         self.assertIs(
             type(ModelWithMyManagerNoDefault._default_manager), PolymorphicManager
         )
-        self.assertIs(type(ModelWithMyManagerNoDefault.base_objects), models.Manager)
 
     def test_user_objects_manager_as_secondary(self):
         self.create_model2abcd()
@@ -855,7 +819,6 @@ class PolymorphicTests(TransactionTestCase):
         self.assertIs(type(ModelWithMyManagerDefault.my_objects), MyManager)
         self.assertIs(type(ModelWithMyManagerDefault.objects), PolymorphicManager)
         self.assertIs(type(ModelWithMyManagerDefault._default_manager), MyManager)
-        self.assertIs(type(ModelWithMyManagerDefault.base_objects), models.Manager)
 
     def test_user_defined_queryset_as_manager(self):
         self.create_model2abcd()
@@ -878,7 +841,6 @@ class PolymorphicTests(TransactionTestCase):
             type(ModelWithMyManager2._default_manager).__name__,
             "PolymorphicManagerFromMyManagerQuerySet",
         )
-        self.assertIs(type(ModelWithMyManager2.base_objects), models.Manager)
 
     def test_manager_inheritance(self):
         # by choice of MRO, should be MyManager from MROBase1.
